BiometricAuthMethod enum

The authentication method used to establish a session.

Inheritance
Available extensions

Values

faceID → const BiometricAuthMethod

iOS Face ID.

touchID → const BiometricAuthMethod

iOS Touch ID.

fingerprint → const BiometricAuthMethod

Android fingerprint sensor.

iris → const BiometricAuthMethod

Android iris / face recognition.

deviceCredential → const BiometricAuthMethod

Device PIN, pattern, or password (system credential).

customPin → const BiometricAuthMethod

Custom app-defined PIN via FallbackHandler.

customPassword → const BiometricAuthMethod

Custom app-defined password via FallbackHandler.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BiometricAuthMethod>
A constant List of the values in this enum, in order of their declaration.