onEvent property
Receives all audit events emitted by the SDK. Plug directly into your existing analytics or logging service.
Implementation
final void Function(BiometricEvent event)? onEvent;
Receives all audit events emitted by the SDK. Plug directly into your existing analytics or logging service.
final void Function(BiometricEvent event)? onEvent;