BiometricFallbackSuccess class

Biometric failed but a fallback succeeded.

Inheritance

Constructors

BiometricFallbackSuccess({required BiometricFallback methodUsed, required BiometricSession session, required String? token})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
methodUsed BiometricFallback
Which fallback method succeeded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session BiometricSession
The newly created session.
final
token String?
The stored token, if any.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>({required T success(BiometricSession session, String? token), required T fallbackSuccess(BiometricFallback methodUsed, BiometricSession session, String? token), required T sessionValid(BiometricSession session, String? token), required T tokenExpired(), required T cancelled(), required T lockedOut(DateTime lockedUntil), required T unavailable(BiometricUnavailableReason reason, String? message), required T invalidated(), required T reauthenticationRequired(String? reason), required T error(String message, Object? cause)}) → T
Pattern-match on all possible outcomes.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited