BiometricUnavailableReason enum

Reason why biometric authentication is unavailable on this device.

Inheritance
Available extensions

Values

notEnrolled → const BiometricUnavailableReason

Device supports biometric but user hasn't enrolled any.

notSupported → const BiometricUnavailableReason

Biometric hardware not present on this device.

passcodeNotSet → const BiometricUnavailableReason

Device has no secure lock screen set.

temporarilyUnavailable → const BiometricUnavailableReason

Too many system-level failures; temporarily unavailable.

disabledByPolicy → const BiometricUnavailableReason

Server policy has disabled biometric authentication.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BiometricUnavailableReason>
A constant List of the values in this enum, in order of their declaration.