TokenStatus enum

Status of a stored token after validation.

Inheritance
Available extensions

Values

valid → const TokenStatus

Token is valid and can be used as-is.

expired → const TokenStatus

Token has expired but may be refreshable.

invalid → const TokenStatus

Token is invalid (tampered, revoked, wrong format, etc).

missing → const TokenStatus

No token was found in storage.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TokenStatus>
A constant List of the values in this enum, in order of their declaration.