biometric_shield_testing library

Testing utilities for the BiometricShield SDK.

Import this in your test files to access mocks, fakes, and test configuration helpers.

import 'package:biometric_shield/biometric_shield_testing.dart';

Classes

AuthenticateCall
Records a call to authenticate for verification in tests.
BiometricShieldMock
A mock implementation of BiometricShieldInterface for testing.
BiometricTestConfig
A config preset that disables all persistence for testing.
FakeBiometricResult
Factory for creating BiometricResult instances for common test scenarios.
FakeBiometricSession
Factory for creating fake BiometricSession instances in tests.
FakeTokenStore
In-memory TokenStoreInterface implementation for testing.