AuthState class sealed

Auth state sealed class for BiometricBuilder.

Represents all possible authentication states that can be passed to the builder function.

Implementers

Constructors

AuthState.authenticated({required BiometricSession session, required String? token})
Authentication succeeded and session is active.
const
factory
AuthState.authenticating()
Authentication is currently in progress.
const
factory
AuthState.failed({required BiometricResult result})
Authentication failed.
const
factory
AuthState.idle()
Idle state — no authentication in progress.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited