autoAuthenticate property
If true, automatically triggers authentication on widget mount.
If false, waits for the caller to explicitly trigger auth via
_BiometricBuilderState.authenticate.
Implementation
final bool autoAuthenticate;
If true, automatically triggers authentication on widget mount.
If false, waits for the caller to explicitly trigger auth via
_BiometricBuilderState.authenticate.
final bool autoAuthenticate;