reauthOnResume property
If true, re-authenticates when app resumes from background and the session has expired.
Implementation
final bool reauthOnResume;
If true, re-authenticates when app resumes from background and the session has expired.
final bool reauthOnResume;