sheetMaxHeight property
Maximum height of the bottom sheet as a fraction of screen height (e.g. 0.4 for 40%).
Implementation
final double? sheetMaxHeight;
Maximum height of the bottom sheet as a fraction of screen height (e.g. 0.4 for 40%).
final double? sheetMaxHeight;