AuthenticateCall class
Records a call to authenticate for verification in tests.
Constructors
- AuthenticateCall({required String reason, String? userId, bool requireFresh = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → String
-
The reason string passed to
authenticate.final - requireFresh → bool
-
Whether requireFresh was set to true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String?
-
The userId passed to
authenticate, if any.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited