FakeBiometricResult class
Factory for creating BiometricResult instances for common test scenarios.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cancelled(
) → BiometricResult - User cancelled.
-
error(
{String message = 'Test error', Object? cause}) → BiometricResult - Platform error.
-
fallbackSuccess(
{BiometricFallback method = BiometricFallback.deviceCredential, BiometricSession? session, String? token = 'fake-token'}) → BiometricResult - A successful fallback authentication.
-
invalidated(
) → BiometricResult - Biometric keys invalidated.
-
lockedOut(
{Duration lockoutDuration = const Duration(minutes: 5)}) → BiometricResult - Locked out for 5 minutes.
-
reauthenticationRequired(
{String? reason = 'Test: refresh token expired'}) → BiometricResult - Re-authentication required (refresh token expired).
-
sessionValid(
{BiometricSession? session, String? token = 'fake-token'}) → BiometricResult - An existing valid session.
-
success(
{BiometricSession? session, String? token = 'fake-token'}) → BiometricResult - A successful biometric authentication.
-
tokenExpired(
) → BiometricResult - Token expired result.
- Biometric unavailable.