FakeBiometricSession class
Factory for creating fake BiometricSession instances in tests.
Provides convenient presets for common test scenarios.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
aboutToExpire(
{String sessionId = 'fake-session-expiring', String userId = 'test-user', BiometricAuthMethod method = BiometricAuthMethod.fingerprint}) → BiometricSession - A session that's about to expire (1 second remaining).
-
active(
{String sessionId = 'fake-session-001', String userId = 'test-user', BiometricAuthMethod method = BiometricAuthMethod.fingerprint, Duration validity = const Duration(minutes: 15)}) → BiometricSession - An active, non-expired session.
-
deviceCredential(
{String sessionId = 'fake-session-credential', String userId = 'test-user', Duration validity = const Duration(minutes: 15)}) → BiometricSession - A device credential (PIN/pattern) session.
-
expired(
{String sessionId = 'fake-session-expired', String userId = 'test-user', BiometricAuthMethod method = BiometricAuthMethod.fingerprint}) → BiometricSession - An expired session.
-
faceID(
{String sessionId = 'fake-session-faceid', String userId = 'test-user', Duration validity = const Duration(minutes: 15)}) → BiometricSession - A Face ID session.