CustomFallbackCallbacks class
Callbacks passed to the custom fallback builder.
The builder calls one of these to signal the result of fallback auth.
Constructors
- CustomFallbackCallbacks({required void onSuccess(), required void onCancel(), required void onFailure()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCancel → void Function()
-
Called when the user cancels fallback authentication.
final
- onFailure → void Function()
-
Called when fallback authentication fails (e.g., wrong PIN).
final
- onSuccess → void Function()
-
Called when the user successfully completes fallback authentication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited